@@ -110,7 +110,7 @@ class WH:
         cons = self.add_constraints()
         obj = cp.Minimize(cp.sum(self.p * self.heat_on))
         prob = cp.Problem(obj, cons)
-        prob.solve(solver=cp.GLPK_MI)
+        prob.solve(solver=self.hems.solver)
 
         if not prob.status == 'optimal':
             cons = self.add_constraints(enforce_bounds=False)
